@@ -3,16 +3,16 @@
 # Copyright 2007-2009 Sun Microsystems Inc. and Joanmarie Diggs
 #
 # This library is free software; you can redistribute it and/or
-# modify it under the terms of the GNU Library General Public
+# modify it under the terms of the GNU Lesser General Public
 # License as published by the Free Software Foundation; either
-# version 2 of the License, or (at your option) any later version.
+# version 2.1 of the License, or (at your option) any later version.
 #
 # This library is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# Library General Public License for more details.
+# Lesser General Public License for more details.
 #
-# You should have received a copy of the GNU Library General Public
+# You should have received a copy of the GNU Lesser General Public
 # License along with this library; if not, write to the
 # Free Software Foundation, Inc., Franklin Street, Fifth Floor,
 # Boston MA  02110-1301 USA.
@@ -28,7 +28,7 @@ __license__   = "LGPL"
 import pyatspi
 
 import orca.debug as debug
-import orca.default as default
+import orca.scripts.default as default
 import orca.input_event as input_event
 import orca.orca as orca
 import orca.rolenames as rolenames
@@ -437,19 +437,17 @@ class Script(default.Script):
                 newText = self.getTextLineAtCaret(newLocusOfFocus)
                 if newText == self.preFindLine:
                     orca.setLocusOfFocus(
-                        event, oldLocusOfFocus, notifyPresentationManager=False)
+                        event, oldLocusOfFocus, notifyScript=False)
                     return
             if newLocusOfFocus.getRole() == pyatspi.ROLE_DRAWING_AREA:
-                orca.setLocusOfFocus(
-                    event, oldLocusOfFocus, notifyPresentationManager=False)
+                orca.setLocusOfFocus(event, oldLocusOfFocus, notifyScript=False)
                 return
 
             utterances = \
                  self.speechGenerator.generateSpeech(newLocusOfFocus)
             speech.speak(utterances)
             self.displayBrailleForObject(newLocusOfFocus)
-            orca.setLocusOfFocus(
-                event, newLocusOfFocus, notifyPresentationManager=False)
+            orca.setLocusOfFocus(event, newLocusOfFocus, notifyScript=False)
             return
 
         # Eliminate unnecessary chattiness in the Search panel.
@@ -464,8 +462,7 @@ class Script(default.Script):
         #
         if newLocusOfFocus.getRole() in [self.ROLE_DOCUMENT,
                                          pyatspi.ROLE_DRAWING_AREA]:
-            orca.setLocusOfFocus(
-                event, newLocusOfFocus, notifyPresentationManager=False)
+            orca.setLocusOfFocus(event, newLocusOfFocus, notifyScript=False)
             return
 
         elif newLocusOfFocus.getRole() == self.ROLE_LINK:
@@ -481,8 +478,7 @@ class Script(default.Script):
                     self.utilities.adjustForRepeats(utterance))
             speech.speak(adjustedUtterances)
             self.displayBrailleForObject(newLocusOfFocus)
-            orca.setLocusOfFocus(
-                event, newLocusOfFocus, notifyPresentationManager=False)
+            orca.setLocusOfFocus(event, newLocusOfFocus, notifyScript=False)
             return
 
         default.Script.locusOfFocusChanged(self, event,
@@ -549,7 +545,7 @@ class Script(default.Script):
             # selected when you arrow to them.  You have to press Space
             # to select the current radio button.  Watch for this.
             #
-            orca.visualAppearanceChanged(event, event.source)
+            self.visualAppearanceChanged(event, event.source)
             return
 
         elif event.type.startswith("object:state-changed:focused") \
@@ -561,8 +557,7 @@ class Script(default.Script):
                      self.speechGenerator.generateSpeech(event.source)
                 speech.speak(utterances)
                 self.displayBrailleForObject(event.source)
-                orca.setLocusOfFocus(
-                    event, event.source, notifyPresentationManager=False)
+                orca.setLocusOfFocus(event, event.source, notifyScript=False)
                 return
 
             elif event.source.getRole() == pyatspi.ROLE_TEXT:
